==> dps-data-model-0.0.18-sources.jar: pl/topteam/dps/model/main_gen/ZebranieZto.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.generic.GenericDPSObject;

public abstract class ZebranieZto extends GenericDPSObject {
    /**
     * ZEBRANIE_ZTO.ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long id;

    /**
     * ZEBRANIE_ZTO.SZABLON_WYDRUKU_ID
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Long szablonWydrukuId;

    /**
     * ZEBRANIE_ZTO.DATA
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date data;

    /**
     * ZEBRANIE_ZTO.DATA_PLAN
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private Date dataPlan;

    /**
     * ZEBRANIE_ZTO.GODZINA_PLAN
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String godzinaPlan;

    /**
     * ZEBRANIE_ZTO.MIEJSCE_PLAN
     *
     * @mbggenerated 2014-03-10 10:45:37
     */
    private String miejscePlan;

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ZEBRANIE_ZTO.ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * ZEBRANIE_ZTO.ID
     *
     * @param id
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return ZEBRANIE_ZTO.SZABLON_WYDRUKU_ID
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Long getSzablonWydrukuId() {
        return szablonWydrukuId;
    }

    /**
     * ZEBRANIE_ZTO.SZABLON_WYDRUKU_ID
     *
     * @param szablonWydrukuId
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setSzablonWydrukuId(Long szablonWydrukuId) {
        this.szablonWydrukuId = szablonWydrukuId;
    }

    /**
     * @return ZEBRANIE_ZTO.DATA
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getData() {
        return data;
    }

    /**
     * ZEBRANIE_ZTO.DATA
     *
     * @param data
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setData(Date data) {
        this.data = data;
    }

    /**
     * @return ZEBRANIE_ZTO.DATA_PLAN
     * @mbggenerated 2014-03-10 10:45:37
     */
    public Date getDataPlan() {
        return dataPlan;
    }

    /**
     * ZEBRANIE_ZTO.DATA_PLAN
     *
     * @param dataPlan
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setDataPlan(Date dataPlan) {
        this.dataPlan = dataPlan;
    }

    /**
     * @return ZEBRANIE_ZTO.GODZINA_PLAN
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getGodzinaPlan() {
        return godzinaPlan;
    }

    /**
     * ZEBRANIE_ZTO.GODZINA_PLAN
     *
     * @param godzinaPlan
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setGodzinaPlan(String godzinaPlan) {
        this.godzinaPlan = godzinaPlan == null ? null : godzinaPlan.trim();
    }

    /**
     * @return ZEBRANIE_ZTO.MIEJSCE_PLAN
     * @mbggenerated 2014-03-10 10:45:37
     */
    public String getMiejscePlan() {
        return miejscePlan;
    }

    /**
     * ZEBRANIE_ZTO.MIEJSCE_PLAN
     *
     * @param miejscePlan
     * @mbggenerated 2014-03-10 10:45:37
     */
    public void setMiejscePlan(String miejscePlan) {
        this.miejscePlan = miejscePlan == null ? null : miejscePlan.trim();
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        ZebranieZto other = (ZebranieZto) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getSzablonWydrukuId() == null ? other.getSzablonWydrukuId() == null : this.getSzablonWydrukuId().equals(other.getSzablonWydrukuId()))
            && (this.getData() == null ? other.getData() == null : this.getData().equals(other.getData()))
            && (this.getDataPlan() == null ? other.getDataPlan() == null : this.getDataPlan().equals(other.getDataPlan()))
            && (this.getGodzinaPlan() == null ? other.getGodzinaPlan() == null : this.getGodzinaPlan().equals(other.getGodzinaPlan()))
            && (this.getMiejscePlan() == null ? other.getMiejscePlan() == null : this.getMiejscePlan().equals(other.getMiejscePlan()));
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getSzablonWydrukuId() == null) ? 0 : getSzablonWydrukuId().hashCode());
        result = prime * result + ((getData() == null) ? 0 : getData().hashCode());
        result = prime * result + ((getDataPlan() == null) ? 0 : getDataPlan().hashCode());
        result = prime * result + ((getGodzinaPlan() == null) ? 0 : getGodzinaPlan().hashCode());
        result = prime * result + ((getMiejscePlan() == null) ? 0 : getMiejscePlan().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-10 10:45:37
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", szablonWydrukuId=").append(szablonWydrukuId);
        sb.append(", data=").append(data);
        sb.append(", dataPlan=").append(dataPlan);
        sb.append(", godzinaPlan=").append(godzinaPlan);
        sb.append(", miejscePlan=").append(miejscePlan);
        sb.append("]");
        return sb.toString();
    }
}

==> dps-data-model-0.0.23-sources.jar: pl/topteam/dps/model/main_gen/ZebranieZto.java <==
package pl.topteam.dps.model.main_gen;

import java.util.Date;
import pl.topteam.dps.model.main_gen.GenericDPSObject;

public abstract class ZebranieZto extends GenericDPSObject {
    /**
     * ZEBRANIE_ZTO.ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long id;

    /**
     * ZEBRANIE_ZTO.SZABLON_WYDRUKU_ID
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Long szablonWydrukuId;

    /**
     * ZEBRANIE_ZTO.DATA
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date data;

    /**
     * ZEBRANIE_ZTO.DATA_PLAN
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private Date dataPlan;

    /**
     * ZEBRANIE_ZTO.GODZINA_PLAN
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String godzinaPlan;

    /**
     * ZEBRANIE_ZTO.MIEJSCE_PLAN
     *
     * @mbggenerated 2014-03-13 16:02:38
     */
    private String miejscePlan;

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    private static final long serialVersionUID = 1L;

    /**
     * @return ZEBRANIE_ZTO.ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public Long getId() {
        return id;
    }

    /**
     * ZEBRANIE_ZTO.ID
     *
     * @param id
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setId(Long id) {
        this.id = id;
    }

    /**
     * @return ZEBRANIE_ZTO.SZABLON_WYDRUKU_ID
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Long getSzablonWydrukuId() {
        return szablonWydrukuId;
    }

    /**
     * ZEBRANIE_ZTO.SZABLON_WYDRUKU_ID
     *
     * @param szablonWydrukuId
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setSzablonWydrukuId(Long szablonWydrukuId) {
        this.szablonWydrukuId = szablonWydrukuId;
    }

    /**
     * @return ZEBRANIE_ZTO.DATA
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getData() {
        return data;
    }

    /**
     * ZEBRANIE_ZTO.DATA
     *
     * @param data
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setData(Date data) {
        this.data = data;
    }

    /**
     * @return ZEBRANIE_ZTO.DATA_PLAN
     * @mbggenerated 2014-03-13 16:02:38
     */
    public Date getDataPlan() {
        return dataPlan;
    }

    /**
     * ZEBRANIE_ZTO.DATA_PLAN
     *
     * @param dataPlan
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setDataPlan(Date dataPlan) {
        this.dataPlan = dataPlan;
    }

    /**
     * @return ZEBRANIE_ZTO.GODZINA_PLAN
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getGodzinaPlan() {
        return godzinaPlan;
    }

    /**
     * ZEBRANIE_ZTO.GODZINA_PLAN
     *
     * @param godzinaPlan
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setGodzinaPlan(String godzinaPlan) {
        this.godzinaPlan = godzinaPlan == null ? null : godzinaPlan.trim();
    }

    /**
     * @return ZEBRANIE_ZTO.MIEJSCE_PLAN
     * @mbggenerated 2014-03-13 16:02:38
     */
    public String getMiejscePlan() {
        return miejscePlan;
    }

    /**
     * ZEBRANIE_ZTO.MIEJSCE_PLAN
     *
     * @param miejscePlan
     * @mbggenerated 2014-03-13 16:02:38
     */
    public void setMiejscePlan(String miejscePlan) {
        this.miejscePlan = miejscePlan == null ? null : miejscePlan.trim();
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public boolean equals(Object that) {
        if (this == that) {
            return true;
        }
        if (that == null) {
            return false;
        }
        if (getClass() != that.getClass()) {
            return false;
        }
        ZebranieZto other = (ZebranieZto) that;
        return (this.getId() == null ? other.getId() == null : this.getId().equals(other.getId()))
            && (this.getSzablonWydrukuId() == null ? other.getSzablonWydrukuId() == null : this.getSzablonWydrukuId().equals(other.getSzablonWydrukuId()))
            && (this.getData() == null ? other.getData() == null : this.getData().equals(other.getData()))
            && (this.getDataPlan() == null ? other.getDataPlan() == null : this.getDataPlan().equals(other.getDataPlan()))
            && (this.getGodzinaPlan() == null ? other.getGodzinaPlan() == null : this.getGodzinaPlan().equals(other.getGodzinaPlan()))
            && (this.getMiejscePlan() == null ? other.getMiejscePlan() == null : this.getMiejscePlan().equals(other.getMiejscePlan()));
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public int hashCode() {
        final int prime = 31;
        int result = 1;
        result = prime * result + ((getId() == null) ? 0 : getId().hashCode());
        result = prime * result + ((getSzablonWydrukuId() == null) ? 0 : getSzablonWydrukuId().hashCode());
        result = prime * result + ((getData() == null) ? 0 : getData().hashCode());
        result = prime * result + ((getDataPlan() == null) ? 0 : getDataPlan().hashCode());
        result = prime * result + ((getGodzinaPlan() == null) ? 0 : getGodzinaPlan().hashCode());
        result = prime * result + ((getMiejscePlan() == null) ? 0 : getMiejscePlan().hashCode());
        return result;
    }

    /**
     * @mbggenerated 2014-03-13 16:02:38
     */
    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append(getClass().getSimpleName());
        sb.append(" [");
        sb.append("Hash = ").append(hashCode());
        sb.append(", id=").append(id);
        sb.append(", szablonWydrukuId=").append(szablonWydrukuId);
        sb.append(", data=").append(data);
        sb.append(", dataPlan=").append(dataPlan);
        sb.append(", godzinaPlan=").append(godzinaPlan);
        sb.append(", miejscePlan=").append(miejscePlan);
        sb.append("]");
        return sb.toString();
    }
}
